@@ -22,6 +22,7 @@ from datamodel.fields import Field
 from datamodel.types import JSON_TYPES
 from datamodel.converters import parse_type
 from datamodel.validation import validator
+from datamodel.exceptions import ValidationError
 from .parsers.encoders import DefaultEncoder
 
 
@@ -256,7 +257,7 @@ class BaseModel(metaclass=ModelMeta):
                 encoder = f.metadata['encoder']
             else:
                 encoder = None
-            # print(f'FIELD {key} = {value}', 'TYPE : ', f.type, type(f.type))
+            ### Factory Value:
             if isinstance(f.type, types.MethodType):
                 raise TypeError(
                     f"DataModel: Wrong type for Column {key}: {f.type}"
@@ -282,7 +283,7 @@ class BaseModel(metaclass=ModelMeta):
                     raise TypeError(
                         f"DataModel: Wrong type for {key}: {f.type}, error: {e}"
                     ) from e
-                print(f'FIELD {key} = {value}', 'TYPE : ', f.type, type(f.type))
+                # print(f'FIELD {key} = {value}', 'TYPE : ', f.type, type(f.type))
                 if isinstance(value, list):
                     try:
                         sub_type = f.type.__args__[0]
@@ -300,7 +301,7 @@ class BaseModel(metaclass=ModelMeta):
                             setattr(self, key, items)
                     except AttributeError:
                         setattr(self, key, value)
-                elif value is None:
+                elif self.is_empty(value):
                     is_missing = isinstance(f.default, _MISSING_TYPE)
                     setattr(self, key, f.default_factory if is_missing else f.default)
                 elif new_val:= parse_type(f.type, value, encoder):
@@ -317,6 +318,18 @@ class BaseModel(metaclass=ModelMeta):
         is_missing = (value == _MISSING_TYPE)
         return callable(value) if not is_missing else False
 
+    def is_empty(self, value) -> bool:
+        if isinstance(value, _MISSING_TYPE):
+            return True
+        elif (value == _MISSING_TYPE):
+            return True
+        elif value is None:
+            return True
+        elif str(value) == '':
+            return True
+        return False
+
+
     def _validation(self) -> None:
         """
         _validation.
@@ -328,7 +341,7 @@ class BaseModel(metaclass=ModelMeta):
             value = getattr(self, f.name)
             annotated_type = f.type
             val_type = type(value)
-            # Fix values of Data:
+            # Fix values of Data based on Default factory
             if hasattr(f, 'default') and self.is_callable(value):
                 try:
                     if value.__module__ != 'typing':
@@ -347,26 +360,41 @@ class BaseModel(metaclass=ModelMeta):
                     )
                     setattr(self, name, None)
             # first: check primary and required:
-            if val_type == type or value == annotated_type or value is None:
-                if f.metadata['primary'] is True:
-                    raise ValueError(
-                        f"Missing Primary Key *{name}*"
-                    )
-                if f.metadata["required"] is True and self.Meta.strict is True:
-                    raise ValueError(
-                        f"Missing Required Field *{name}*"
-                    )
-                elif f.metadata["nullable"] is False and self.Meta.strict is True:
-                    raise ValueError(
-                        f"Missing Field *{name}* when Nullable is False."
-                    )
+            if val_type == type or value == annotated_type or self.is_empty(value):
+                try:
+                    if f.metadata['primary'] is True:
+                        raise ValueError(
+                            f"::{self.modelName}:: Missing Primary Key *{name}*"
+                        )
+                except KeyError:
+                    pass
+                try:
+                    if f.metadata["required"] is True and self.Meta.strict is True:
+                        raise ValueError(
+                            f"::{self.modelName}:: Missing Required Field *{name}*"
+                        )
+                except KeyError:
+                    pass
+                try:
+                    if f.metadata["nullable"] is False and self.Meta.strict is True:
+                        raise ValueError(
+                            f"::{self.modelName}:: Cannot null *{name}*"
+                        )
+                except KeyError:
+                    pass
             else:
                 # capturing other errors from validator:
                 error = validator(f, name, value, annotated_type)
                 if error:
                     errors[name] = error
         if errors:
-            print("=== ERRORS ===")
+            if self.Meta.strict is True:
+
+                raise ValidationError(
+                    message="""There are errors in your data.
+                    Hint: please check the "payload" attribute in the exception.""",
+                    payload=errors
+                )
             print(errors)
             object.__setattr__(self, "__valid__", False)
         else:
